@@ -3,7 +3,7 @@ package Mnet;
 # version number used by Makefile.PL
 #   these should be set to "dev", expect when creating a new release
 #   refer to developer build notes in Makefile.PL for more info
-our $VERSION = "5.09";
+our $VERSION = "5.10";
 
 =head1 NAME
 
@@ -19,7 +19,7 @@ Mnet - Testable network automation and reporting
     #   use --help to list all options, or --help <option>
     #   use --device <address> to connect to device with logging
     #   use --batch <file.batch> to process multiple --device lines
-    #   add --report csv:<file.csv> to create output csv repory file
+    #   add --report csv:<file.csv> to create an output csv report file
     #   add --record <file.test> to create replayable test file
     #   use --test --replay <file.test> to show script test diff
 
@@ -153,9 +153,12 @@ Or downloaded and installed from L<https://github.com/menzascripting/Mnet>
     tar -xzf Mnet-X.y.tar.gz
     cd Mnet-X.y
     perl Makefile.PL  # INSTALL_BASE=/specify/path
+    make test
     make install
 
-Check your PERL5LIB environment variable if INSTALL_BASE was used, above.
+Check your PERL5LIB environment variable if INSTALL_BASE was used, or if you
+copied the lib/Mnet directory somewhere instead of using Makefile.PL. Refer
+to L<ExtUtils::MakeMaker> for more information
 
 =head1 AUTHOR
 
